import { NextFunction, Request, Response } from 'express';
import { Logger } from '../log/logger';
import { IServiceDescriptor } from '../model/serviceDescriptor';
import { IAuthRequest } from './model/authRequest';
import { ICoronerRequestOption } from './model/authRequestOptions';
import { IServerConfiguration } from './model/serverConfiguration';
/**
 * Identity manager
 */
export declare class IdentityManager {
    private descr;
    authenticated: {
        [index: string]: object;
    };
    /**
     * Sets the coroned callback function - the funciton that will be
     * executed by the identity manager, when a new coronerd instance
     * registers. Setting a new coronerd callback will also invoke the
     * callback funciton with all saved unique ip addresses.
     * @param callback: callback function that retrieves a registered coronerd ip address
     */
    coronerdCallback(callback: (ip: string, alreadyRegistered: boolean) => Promise<void> | void): void;
    private registeredUniverses;
    /**
     * Coronerd callback function
     */
    private onCoronerCallback?;
    private logger?;
    private httpsAgent;
    constructor(descr: IServiceDescriptor, logger?: Logger);
    setLogger(logger: Logger): void;
    serviceRequest(opts?: ICoronerRequestOption): ((request: Request, response: Response, next: NextFunction) => Promise<void>)[];
    /**
     * Generate a middleware for Express.js which validates a request
     * by comparing universe/project data avaialble in the request object
     * with universe/project data available in the Authenticated request.
     *
     * This middleware must be used after the authenticateRequest.
     * @param dataProvider universe/project provider.
     */
    validateProjectAccess<TRequest extends IAuthRequest>(dataProvider: (req: TRequest) => {
        universe: string;
        project?: string;
    }): (req: Request, res: Response, next: NextFunction) => void;
    /**
     * Generate a middleware for Express.js, which authenticates a request given
     * its URL and session token, provided by an earlier callback in
     * req.coronerAuth.
     * Upon success, the configuration data will be in req.coronerAuth.cfg.
     */
    authenticateRequest(): (request: Request, _: Response, next: NextFunction) => Promise<void>;
    /**
     * This assumes route has already passed authentication through authenticateRequest
     * and uses /api/config result from that to check projects.
     */
    checkProjectAccess(request: Request, response: Express.Response, projects: string[] | number[]): boolean;
    /**
     * Unconditionally set projectValidated flag to true.
     * Allows service routes that do not need project validation to procceed with
     * typical Express send method.
     */
    bypassProjectAccessCheck(response: Express.Response): void;
    /**
     * Use coronerd auth method to validate url and session token provided by user
     * For Express apps, consider using the authenticateRequest middleware instead
     * @param url coronerd url
     * @param token coronerd token
     */
    authenticate(url: string, token: string): Promise<IServerConfiguration>;
    /**
     * Login to a coronerd.
     * @param Coronerd base URL to login to
     */
    loginCoronerd(coronerdUrl: string): Promise<IServerConfiguration | undefined>;
    /**
     * Retrieves the zeroconf from a coronerd
     * to store data for later client consumption.
     */
    private retrieveAndStoreCoronerdInfo;
    /**
     * @deprecated: these methods will be removed in new backtrace-service  update
     * Check if authtoken is a valid token generated by coronerd
     * @param universeUrl url to coronerd universe
     * @param authToken user token
     */
    isValidToken(universeUrl: string, authToken: string): Promise<boolean>;
    /**
     * @deprecated: these methods will be removed in new backtrace-service  update
     * Get Backtrace configuration
     * @param universeUrl url to coronerd universe
     * @param authToken user token
     */
    getConfiguration(universeUrl: string, authToken: string): Promise<IServerConfiguration | undefined>;
    private generateHmac;
    private checkHmac;
    private sanitizeHeader;
    private log;
    private readCoronerAuthInfo;
}
